/* LSAGPI                                       */
/* Desarrollado por Miguel Angel Pescador Santirso  */
/* mescadorsantirso@gmail.com                       */

/* LICENCIA X11/MIT
Copyright (c) 2010 Miguel Angel Pescador Santirso

Se autoriza, de forma gratuita, a cualquier
persona que ha obtenido una copia de este software y
archivos asociados de documentación (el "Software"), para tratar en el
Software sin restricción, incluyendo sin ninguna limitación en lo que concierne
los derechos para usar, copiar, modificar, fusionar, publicar,
distribuir, sublicenciar, y / o vender copias de este
Software, y para permitir a las personas que usan el Software para
hacerlo, con sujeción a las siguientes condiciones:

El aviso de copyright anterior y este aviso de permiso
se incluirá en todas las copias o partes sustanciales de
este Software.

EL SOFTWARE SE ENTREGA "TAL CUAL", SIN GARANTÍA DE NINGÚN
TIPO, EXPRESA o implícita, no limitado a la GARANTÍAS DE
COMERCIALIZACIÓN, CAPACIDAD DE HACER Y DE NO INFRACCIÓN DE COPYRIGHT. EN NINGÚN
CASO LOS AUTORES O TITULARES DEL COPYRIGHT SERÁN RESPONSABLES DE
NINGUNA RECLAMACIÓN, daños o OTRAS RESPONSABILIDADES,
YA SEA EN UN LITIGIO, agravio o DE OTRO MODO,
DERIVADAS DE, FUERA DE O EN CONEXION CON EL
SOFTWARE SU UTILIZACIÓN U OTRAS OPERACIONES EN EL SOFTWARE.
*/


package lsagpi;

import java.io.File;
import java.util.Hashtable;
import java.util.Enumeration;
import javax.swing.*;
import javax.swing.filechooser.*;

/**
 * Clase que define el filtro para carga de archivos *.adv.
 * @author Miguel Angel Pescador Santirso
 */
public class FiltroADV extends FileFilter {

    private static String TIPO_DESCONOCIDO = "Tipo Desconocido";
    private static String ARCHIVO_OCULTO = "Archivo Oculto";

    private Hashtable filtros = null;
    private String descripcion = null;
    private String descripcionCompleta = null;
    private boolean usarExtensionesEnDescripcion = true;

    /**
     * Constructor básico de la clase.
     */
    public FiltroADV() {
	this.filtros = new Hashtable();
    }

    /**
     * Constructor recibiendo la extension a filtrar.
     * @param extension Extension a filtrar.
     */
    public FiltroADV(String extension) {
	this(extension,null);
    }

    /**
     * Constructor recibiendo la extensión a filtrar y una descripcion.
     * @param extension Extension a filtrar.
     * @param descripcion Descripción de la extensión.
     */
    public FiltroADV(String extension, String descripcion) {
	this();
	if(extension!=null) addExtension(extension);
 	if(descripcion!=null) setDescripcion(descripcion);
    }

    /**
     * Constructor recibiendo un array de extensiones a filtrar.
     * @param filtros Array con las extensiones a filtrar.
     */
    public FiltroADV(String[] filtros) {
	this(filtros, null);
    }

    /**
     * Constructor recibiendo array de extensiones a filtrar y descipción de estas extensiones.
     * @param filtros Array de extensiones a filtrar.
     * @param descripcion Descripción de este array de extensiones.
     */
    public FiltroADV(String[] filtros, String descripcion) {
	this();
	for (int i = 0; i < filtros.length; i++) {
	    // add filters one by one
	    addExtension(filtros[i]);
	}
 	if(descripcion!=null) setDescripcion(descripcion);
    }

    /**
     * Heredado de FileFilter metodo de aceptación de que el archivo cumple la extension.
     * @param f Archivo a Filtrar.
     * @return true si esta dentro del filtro o false en otro caso.
     */
    public boolean accept(File f) {
	if(f != null) {
	    if(f.isDirectory()) {
		return true;
	    }
	    String extension = getExtension(f);
	    if(extension != null && filtros.get(getExtension(f)) != null) {
		return true;
	    };
	}
	return false;
    }

   /**
    * Coge la extensión del archivo enviado.
    * @param f Archivo enviado.
    * @return Extension del archivo.
    */
     public String getExtension(File f) {
	if(f != null) {
	    String nombrearchivo = f.getName();
	    int i = nombrearchivo.lastIndexOf('.');
	    if(i>0 && i<nombrearchivo.length()-1) {
		return nombrearchivo.substring(i+1).toLowerCase();
	    };
	}
	return null;
    }

    /**
     * Añade una extension al filtro.
     * @param extension Extensión a añadir.
     */
    public void addExtension(String extension) {
	if(filtros == null) {
	    filtros = new Hashtable(5);
	}
	filtros.put(extension.toLowerCase(), this);
	descripcionCompleta = null;
    }


  /**
   * Método heredado de FileFilter. Devuelve la descripción del filtro.
   * @return Descripción del filtro String.
   */
    public String getDescription() {
	if(descripcionCompleta == null) {
	    if(descripcion == null || estaExtensionEnDescripcion()) {
 		descripcionCompleta = descripcion==null ? "(" : descripcion + " (";
		// build the description from the extension list
		Enumeration extensiones = filtros.keys();
		if(extensiones != null) {
		    descripcionCompleta += "." + (String) extensiones.nextElement();
		    while (extensiones.hasMoreElements()) {
			descripcionCompleta += ", ." + (String) extensiones.nextElement();
		    }
		}
		descripcionCompleta += ")";
	    } else {
		descripcionCompleta = descripcion;
	    }
	}
	return descripcionCompleta;
    }
    /**
     * Cambia o selecciona la descripción del filtro
     * @param descripcion Descripción del filtro.
     */
    public void setDescripcion(String descripcion) {
	this.descripcion = descripcion;
	descripcionCompleta = null;
    }

    /**
     * Define si se usarán las extensiones en la descripción del filtro.
     * @param b Booleano true usa las extensiones en la descripción false no las usa.
     */
    public void setExtensionEnDescripcion(boolean b) {
	usarExtensionesEnDescripcion = b;
	descripcionCompleta = null;
    }
    /**
     * Comprueba si se usan las extensiones en la descripción.
     * @return true si las usa false sino las usa.
     */
    public boolean estaExtensionEnDescripcion() {
	return usarExtensionesEnDescripcion;
    }
}
